@@ -30,7 +30,7 @@ var NAVTREE =
       [ "Starting Points", "index.html#main_startpoints", null ]
     ] ],
     [ "AV1 Developer's Guide", "index.html#av1_guide", null ],
-    [ "Support Options & FAQ", "index.html#main_support", null ],
+    [ "Support Options &amp; FAQ", "index.html#main_support", null ],
     [ "RFC2119 Keywords", "rfc2119.html", [
       [ "MUST", "rfc2119.html#MUST", null ],
       [ "MUST NOT", "rfc2119.html#MUSTNOT", null ],
@@ -40,19 +40,7 @@ var NAVTREE =
     ] ],
     [ "CHANGELOG", "changelog.html", null ],
     [ "README.md", "readme.html", null ],
-    [ "Usage", "usage.html", [
-      [ "Important Data Types", "usage.html#usage_types", [
-        [ "Contexts", "usage.html#usage_ctxs", null ],
-        [ "Interfaces", "usage.html#usage_ifaces", null ]
-      ] ],
-      [ "Features", "usage.html#usage_features", null ],
-      [ "Initialization", "usage.html#usage_init", null ],
-      [ "Error Handling", "usage.html#usage_errors", null ],
-      [ "Decoding", "usage_decode.html", [
-        [ "Frame Iterator Based Decoding", "usage_decode.html#usage_frame_iter", null ]
-      ] ],
-      [ "Encoding", "usage_encode.html", null ]
-    ] ],
+    [ "Usage", "usage.html", "usage" ],
     [ "AV1 DECODER GUIDE", "decoder_guide.html", null ],
     [ "AV1 ENCODER GUIDE", "encoder_guide.html", [
       [ "Introduction", "encoder_guide.html#architecture_introduction", [
@@ -84,7 +72,7 @@ var NAVTREE =
         [ "The Main Rate Control Loop", "encoder_guide.html#architecture_enc_rc_loop", null ],
         [ "Fixed Q Mode", "encoder_guide.html#architecture_enc_fixed_q", null ]
       ] ],
-      [ "GF/ ARF Frame Groups & Hierarchical Coding", "encoder_guide.html#architecture_enc_frame_groups", [
+      [ "GF/ ARF Frame Groups &amp; Hierarchical Coding", "encoder_guide.html#architecture_enc_frame_groups", [
         [ "Main Data Structures", "encoder_guide.html#architecture_enc_frame_groups_data", null ],
         [ "Frame Groups", "encoder_guide.html#architecture_enc_frame_groups_groups", null ],
         [ "GF / ARF Group Length Determination", "encoder_guide.html#architecture_enc_gf_length", null ],
@@ -114,26 +102,10 @@ var NAVTREE =
             [ "Quantized level optimization", "encoder_guide.html#architecture_entropy_coef_opt", null ]
           ] ]
         ] ]
-      ] ]
-    ] ],
-    [ "Sample Code", "samples.html", [
-      [ "decode_to_md5", "example_decode_to_md5.html", null ],
-      [ "decode_with_drops", "example_decode_with_drops.html", null ],
-      [ "simple_decoder", "example_simple_decoder.html", null ],
-      [ "lossless_encoder", "example_lossless_encoder.html", null ],
-      [ "set_maps", "example_set_maps.html", null ],
-      [ "simple_encoder", "example_simple_encoder.html", null ],
-      [ "twopass_encoder", "example_twopass_encoder.html", null ],
-      [ "scalable_encoder", "example_scalable_encoder.html", null ],
-      [ "svc_encoder_rtc", "example_svc_encoder_rtc.html", null ],
-      [ "aom_cx_set_ref", "example_aom_cx_set_ref.html", null ],
-      [ "lightfield_encoder", "example_lightfield_encoder.html", null ],
-      [ "lightfield_tile_list_decoder", "example_lightfield_tile_list_decoder.html", null ],
-      [ "lightfield_decoder", "example_lightfield_decoder.html", null ],
-      [ "lightfield_bitstream_parsing", "example_lightfield_bitstream_parsing.html", null ],
-      [ "aomdec", "example_aomdec.html", null ],
-      [ "aomenc", "example_aomenc.html", null ]
+      ] ],
+      [ "SIMD usage", "encoder_guide.html#architecture_simd", null ]
     ] ],
+    [ "Sample Code", "samples.html", "samples" ],
     [ "README.md", "LREADME.html", [
       [ "AV1 Codec Library", "LREADME.html#autotoc_md0", [
         [ "Contents", "LREADME.html#autotoc_md1", null ],
@@ -168,6 +140,7 @@ var NAVTREE =
           ] ]
         ] ],
         [ "Coding style", "LREADME.html#coding-style", null ],
+        [ "License header", "LREADME.html#license-header", null ],
         [ "Submitting patches", "LREADME.html#submitting-patches", [
           [ "Login cookie", "LREADME.html#login-cookie", null ],
           [ "Contributor agreement", "LREADME.html#contributor-agreement", null ],
@@ -209,17 +182,18 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "LREADME.html",
-"encoder_guide.html#architecture_enc_gf_structure",
-"group__aom__encoder.html#ga758649aa6cd9fefb15ad888489884a38",
-"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca7cbf0a1ff28bf7c460f6d86d63b30842",
-"group__tpl__modelling.html#gacb25270842c5ab92d1d90a211df955e5",
-"structAV1__COMP.html#a8431a87c6d3ed7cacf1d1d4b53eb15b1",
-"structCommonTileParams.html#a8842e296add2a242e4aaf0fcae574f9b",
-"structMB__MODE__INFO.html#a89abe2416d8601545822281a59f07105",
-"structRestoreStateBuffers.html",
-"structaom__ext__part__funcs.html#a0df62dada4f6083dfa4557f0bebb16c9",
-"structmacroblock.html#a23d3a28fb6cc558faf0328711dee1eed"
+"encoder_guide.html#architecture_enc_gf_length",
+"group__aom__encoder.html#ga5a44302260efb45ebf560f7fb0b4352b",
+"group__codec.html#gad4bd9523583de840a940dbedb6a34d58",
+"group__rate__control.html#gae9eddc0e6469d28bd0429c03efe97544",
+"structAV1__COMP.html#a4ac2ac3d57f1620126ab34d1f19f2943",
+"structCommonModeInfoParams.html#a715f2b0431a451bcda33619e62be23f9",
+"structLAYER__CONTEXT.html",
+"structRateControlCfg.html#ad68d50f3297bc20648f9875ae3804fe4",
+"structaom__codec__enc__cfg.html#a61837750dea1315878b53e2767d9716b",
+"structcfg__options.html#a573d9454ec8f7f909b469c210d2dbbdf"
 ];
 
-var SYNCONMSG = 'click to disable panel synchronisation';
-var SYNCOFFMSG = 'click to enable panel synchronisation';
\ No newline at end of file
+var SYNCONMSG = 'click to disable panel synchronization';
+var SYNCOFFMSG = 'click to enable panel synchronization';
+var LISTOFALLMEMBERS = 'List of all members';
\ No newline at end of file
