@@ -1,6 +1,6 @@
 var structMB__RD__RECORD =
 [
-    [ "tx_rd_info", "structMB__RD__RECORD.html#ac1603fb6384aa8012145276dda2ecdf8", null ],
+    [ "mb_rd_info", "structMB__RD__RECORD.html#aa5763b50c2bc8ae224db1db36c2aea63", null ],
     [ "index_start", "structMB__RD__RECORD.html#ac92c280b73da8242be18b61476df8317", null ],
     [ "num", "structMB__RD__RECORD.html#ae9b214473b4f1801efa4ea8582050a29", null ],
     [ "crc_calculator", "structMB__RD__RECORD.html#af7e8795f2e9be94ef8b3ebf68f2a2387", null ]
